@@ -467,7 +467,7 @@ Ext.define('MP.data.MetaData', {
 
                     var lstore = Ext.create('Ext.data.Store', {
                         model: model,
-                        pageSize: lup.pageSize || 0,
+                        pageSize: lup.pageSize === undefined ? 999 : lup.pageSize,
                         autoLoad: !remoteFilter || !remoteSort,
                         remoteFilter: remoteFilter,
                         remoteSort: remoteSort,
@@ -486,12 +486,43 @@ Ext.define('MP.data.MetaData', {
                     });
                     lstore.implicitModel = true;
 
-                    var listConfig = undefined;
+                    var listConfig = {};
+
                     if(lup.innerTpl) {
-                        listConfig = {
-                            getInnerTpl: Ext.bind(function() {
-                                return this.innerTpl;
-                            }, lup)
+                        listConfig.getInnerTpl = Ext.bind(function() {
+                            return this.innerTpl;
+                        }, lup);
+                    }
+
+                    if(lup.pageSize !== undefined) {
+                        listConfig.createPagingToolbar = function() {
+                            return Ext.widget('pagingtoolbar', {
+                                id: this.id + '-paging-toolbar',
+                                pageSize: this.pageSize,
+                                store: this.dataSource,
+                                border: false,
+                                ownerCt: this,
+                                ownerLayout: this.getComponentLayout(),
+                                getPagingItems: function() {
+                                    var items;
+
+                                    items = Ext.toolbar.Paging.prototype.getPagingItems.call(this);
+
+                                    // Keep only the buttons
+                                    items = Ext.Array.filter(items, function(i) {
+                                        return i.itemId == 'first' ||
+                                            i.itemId == 'prev' ||
+                                            i.itemId == 'next' ||
+                                            i.itemId == 'last';
+                                    });
+
+                                    // Force horizontal centering
+                                    items.unshift('->');
+                                    items.push('->');
+
+                                    return items;
+                                }
+                            });
                         };
                     }
 
@@ -506,7 +537,7 @@ Ext.define('MP.data.MetaData', {
                         selectOnFocus: true,
                         allowBlank: nullable,
                         minChars: 3,
-                        pageSize: lup.pageSize || 0,
+                        pageSize: lup.pageSize,
                         listConfig: listConfig
                     });
                 } else {
